get_error_hierarchy

Function get_error_hierarchy 

pub(crate) fn get_error_hierarchy(error_code: i64) -> Vec<ErrorCategory>
Returns the error hierarchy for a given error code

This function returns the category chain for an error code, from most specific to most general (e.g., [DatabaseTransient, Retryable]).